@@ -1,11 +1,22 @@
 # -*- coding: utf-8 -*-
-#~ /***************************************************************************
- #~ *            CPConstants.py
- #~ *
- #~ *  Mon Feb 23 11:21:36 2004
- #~ *  Copyright  2004  Stas Z
- #~ *  stas.zytkiewicz@gmail.com
- #~ ****************************************************************************/
+
+# Copyright (c) 2006 Stas Zykiewicz <stas.zytkiewicz@gmail.com>
+#
+#           CPConstants.py
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of version 2 of the GNU General Public License
+# as published by the Free Software Foundation.  A copy of this license should
+# be included in the file GPL-2.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Library General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+
 CPC_DEBUG = 0
 ## CPConstants
 ## This file provides constants used by all the childsplay modules.
@@ -59,6 +70,14 @@ RCFILES = None # Can we use configuration files
 SPLASH = True # do we want a splash  
 helptext = "Not much help here yet, look at the manpage and docs."
 
+# colors
+RED = (255,0,0)
+GREEN = (0,255,0)
+BLUE = (0,255,0)
+WHITE = (255,255,255)
+BLACK = (0,0,0)
+GREY = (170,170,170)
+DARK_GREY = (100,100,100)
 ## fribidi support. Used for RTL locales
 # This is to signal that we running under a RTL locale like Hebrew or Arabic
 # Only Hebrew is supported until now
