@@ -3,10 +3,10 @@
 """
      Copyright (C) 2002-2006 Stas Z. <stas.zytkiewicz@gmail.com>
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
- any later version.
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of version 2 of the GNU General Public License
+ as published by the Free Software Foundation.  A copy of this license should
+ be included in the file GPL-2.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +14,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with this program; see the file COPYING.  If not, write to
+ along with this program; see the file GPL-2.  If not, write to
  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
  Childsplay - A suite of educational games for young children.
@@ -57,6 +57,7 @@ try:
     from CPConstants import *
     import pyassetmlSDL
 except ImportError,info:
+    trace_error()
     print >> sys.stderr, "Error importing childsplay module\n",info
     sys.exit(1)
 
@@ -67,7 +68,8 @@ rcdic_defaults = {'default':{'__name__':'default',\
                             'fullscr':1,\
                             'language':'system',\
                             'exclude_games':'',\
-                            'letter_size':'normal'}}
+                            'letter_size':'normal',
+                            'kiosk_mode':'no'}}
 
 if CPDEBUG: print "sys.argv",sys.argv
 if len(sys.argv) > 1:
@@ -78,6 +80,8 @@ if len(sys.argv) > 1:
             fullscr = None
         elif item == '--no-splash':
             SPLASH = None
+        elif item == '--kiosk-mode':
+            kioskmode = 1
         elif item == '--version':
             print version.version
             raise SystemExit
@@ -109,17 +113,6 @@ except ImportError, info:
 pygame.init()
 if CPDEBUG: print "mixer settings on init",pygame.mixer.get_init()
 
-###### Moved into CPConstants ########
-### Check if there's a childsplay dir in the home directory
-##if sys.platform == 'win32':
-##    try:
-##      HOMEDIR = os.path.join(os.environ['HOMEDRIVE'],os.environ['HOMEPATH'],HOME_DIR_NAME)
-##    except:
-##        # for win 98 ??
-##        HOMEDIR = os.path.join(os.environ['HOMEPATH'],HOME_DIR_NAME)
-##else:
-##   HOMEDIR = os.path.join(os.environ['HOME'],HOME_DIR_NAME)
-
 tree = HOME_DIR_TREE.replace(';',os.sep)
 for piece in tree.split(','):
     piece = os.path.join(HOMEDIR,piece)
@@ -141,15 +134,8 @@ if not os.path.exists(dest):
         print >> sys.stderr, info
 
 ## check and get rc parser object
-
-try:
-    RcParser_module = import_module(os.path.join(BASEDIR,'ConfParser.py'))
-except ImportError, info:
-    print >> sys.stderr, "Can\'t import module ",info
-    trace_error()
-    print >> sys.stderr,"Using configuration defaults"
-else:
-    RCFILES = 1
+import ConfigParser
+RCFILES = 1
 
 def get_rc(file):
     """ Loads and pars a config file and puts it in a dic.
@@ -160,14 +146,14 @@ def get_rc(file):
     file = name of the module rcfile, without the path.
     """
     file,spam = os.path.splitext(file)
-    rcobj = RcParser_module.ConfParser()
+    rcobj = ConfigParser.SafeConfigParser()
     try:
         rcobj.read(os.path.join(HOME_RCDIR,file))
-    except (RcParser_module.ParsingError,Exception):
+    except (ConfigParser.ParsingError,Exception):
         trace_error()
         try:
             rcobj.read(os.path.join(RCDIR,file))
-        except (RcParser_module.ParsingError,Exception):
+        except (ConfigParser.ParsingError,Exception):
             trace_error()
         return None
     rcdic = {}
@@ -195,15 +181,17 @@ def get_rc(file):
 def set_globalrc(dic):
     """Here we check and make sure the rcdic is valid and also set some
     global constants to get easy access to the rc values"""
-    global rcdic,fullscr,LANG,EXCLUDE_GAMES
+    global rcdic,fullscr,LANG,EXCLUDE_GAMES,kioskmode
     #print "rcdic",rcdic
     try:
         fullscr = int(rcdic['default']['fullscr'])
         LANG = rcdic['default']['language']
         EXCLUDE_GAMES = rcdic['default']['exclude_games']
+        kioskmode = rcdic['default']['kiosk_mode']
     except (KeyError,ValueError,TypeError),info:
         print >> sys.stderr," Problems reading the childsplay config file,\n",\
-                info,"\n using the defaults and replacing the corrupt rc file"
+                info,"\n using the defaults and replacing the corrupt rc file\n",\
+                
         exc = sys.exc_info()[0]
         print exc
         if exc is exceptions.KeyError:
@@ -219,25 +207,30 @@ else:
     rcdic = rcdic_defaults
 set_globalrc(rcdic)
 
+# Setup the ChildsplayGoodies object for the games
+CPGoodies = ChildsplayGoodies()
+# Add some rc variables to ChildsplayGoodies to share between modules
+CPGoodies.kioskmode = kioskmode
 # i18n, put a lot of exception caches because locale stuff keeps crashing
 # on badly configured platforms. Mac OSX locale support is totally broken :-( 
 try:
     STDLOC,LOCALE_RTL = set_locale(LANG)
 except Exception,info:
     print >> sys.stderr,info
-    ChildsplayGoodies.language = 'en'
+    CPGoodies.language = 'en'
     STDLOC,LOCALE_RTL = 'en',None
 try:
     # Add support for the LANGUAGE env var.
-    ChildsplayGoodies.language = STDLOC.split('@')[0].split('.')[0].split('_')[0]
+    CPGoodies.language = STDLOC.split('@')[0].split('.')[0].split('_')[0]
 except Exception,info:
     print >> sys.stderr,info
-    ChildsplayGoodies.language = 'en'
+    CPGoodies.language = 'en'
     STDLOC,LOCALE_RTL = 'en',None
 if LOCALE_RTL and pyfribidi and STDLOC in ['he','ar']:
-    ChildsplayGoodies.locale_rtl = True
-    ChildsplayGoodies.pyfribidi = pyfribidi
-    
+    CPGoodies.locale_rtl = True
+    CPGoodies.pyfribidi = pyfribidi
+
+
 if CPDEBUG: 
     print "Childsplay locale set to %s" % STDLOC
     print "Bidirectional flag is set to %s" % LOCALE_RTL
@@ -468,26 +461,7 @@ class Score:
             self._put_sheet()
         self.clear_scr()
         return flag #trigger game over screen or not. Not in use, yet
-    
-    def _get_key(self):
-        """ Basic edeting function, used in the 'give your name'"""
-        
-        key_map = None # Used as the default keymapping, see function map_keys()
-        if LOCALE_RTL and STDLOC:
-            key_map = {'he':he_key_map,
-                        'ar':ar_key_map}[STDLOC]
-        if STDLOC == 'ru': key_map = ru_key_map
-        event = pygame.event.poll()
-        if event.type is KEYDOWN:
-            if 65<event.key<123 :
-                surf,spam = font2surf(map_keys(key_map,event.unicode),self.sc_fsize,self.sc_fcol,self.hsc_ttf)
-                return surf,event.unicode
-            elif event.key is K_BACKSPACE:
-                return None,'back'
-            elif event.key is K_RETURN:
-                return None,'end'
-        return None,None
-    
+
     def _high_score(self,name,score):
         """ This starts the whole high-score event, usses it's own eventloop and
          takes care of everything"""
@@ -546,7 +520,7 @@ class Contr(Score):
     def __init__(self):
                        
         ## Set icon for the window manager ##    
-        file = os.path.join(DATADIR,'chpl-icon-48.xpm')
+        file = os.path.join(DATADIR,'logo_cp_32x32.xpm')
         try:
             surface = pygame.image.load(file)
         except pygame.error:
@@ -554,7 +528,6 @@ class Contr(Score):
             print >> sys.stderr,'Could not load image "%s"\n %s'%(file, pygame.get_error())
         surface.set_colorkey(surface.get_at((0, 0)), RLEACCEL)
         pygame.display.set_icon(surface)
-        ChildsplayGoodies.scorething = self.update_scorething       
         self.tuxplace = 20
         self.tuxrects = []
         #self.mainmenurects = []
@@ -694,7 +667,7 @@ class Contr(Score):
         dirtyrects = []
         self.sdim.dim(darken_factor=180,color_filter=(51,10,10))
         #sdim.dim(darken_factor=200,color_filter=(9,247,19)) # Used for testing
-        
+        # TODO: place holder for kioskmode stuff
         x= 100
         y= 200
         fcol = (255,0,0)
@@ -721,6 +694,11 @@ class Contr(Score):
             clock.tick(30)
             #events = pygame.event.get()
             event = pygame.event.poll()
+            if kioskmode:
+                pass
+                # placeholder: setup virtual keyboard
+                # should return the users choice which can be checked in _check_ask_exit_value
+                # the virt keyb should destroy itself when the user hits enter.
             if event.type == KEYDOWN:
                 k = 0
                 m = pygame.key.get_mods()
@@ -735,13 +713,9 @@ class Contr(Score):
                 if not 31 < k < 127:
                     continue
                 user_key = ord(map_keys(key_map,chr(k)))
-                if STDLOC in ['he','ar','ru']:
-                    endkey = ord(_("y"))
-                else:
-                    endkey = ord(_("y").lower())
-                if user_key != endkey:
-                    stop = 1
+                if not self._check_ask_exit_value(user_key):
                     break
+                stop = 1
                 self.sdim.dim(darken_factor=255,color_filter=(0,0,0))
                 surf,size = font2surf(_("Shutting down....."),72,(207,55,48),self.ttf)
                 Snd.mainmusic.stop()
@@ -758,7 +732,21 @@ class Contr(Score):
         self.sdim.undim()
         self.screen.set_clip(oldclip)
         return 0
-            
+    
+    def _check_ask_exit_value(self,user_key):
+        """This is a separate method so that we can use it in kiosk mode also
+        This will return 0 for 'no' or 1 for 'yes' in answer to the 'really quit'
+        question."""
+        if STDLOC in ['he','ar','ru']:
+            endkey = ord(_("y"))
+        else:
+            endkey = ord(_("y").lower())
+        if user_key != endkey:
+            v = 0
+        else:
+            v = 1
+        return v       
+
     def update_scorething(self,score):
         """ Update and blit the score display to the main screen"""
         if score < 0: return
@@ -919,10 +907,12 @@ def main():
     global screendim,game_score
     
     c  = Contr()# Start master control
+    CPGoodies.scorething = c.update_scorething   
     Assets_snd.get_assets('music1.ogg', Snd)# will become Snd.music1
     Snd.galaga = load_sound(os.path.join(DATADIR,'Galaga1.ogg'))
     Snd.dub = load_sound(os.path.join(DATADIR,'dub.ogg'))
-    music_collection = [Snd.music1,Snd.galaga,Snd.dub]
+    Snd.thanks = load_sound(os.path.join(DATADIR,'thanks.ogg'))
+    music_collection = [Snd.music1,Snd.galaga,Snd.dub,Snd.thanks]
     #modul = 'Menu'
     screendim = Dimmer(keepalive=1) # dimmer is used for screen copying
     screendim.dim(darken_factor=0) # just stores a copy in Dimmer.buffer
@@ -963,7 +953,10 @@ def main():
             obj = game_module.Game
             c.screen.set_clip(0,0,800,500)
             c.backgr.set_clip(0,0,800,500)
-            game = apply(obj,(c.screen,c.backgr,plug_rcdic,BASEDIR,MODULESDATADIR))# call game constructor
+            
+            game = apply(obj,(c.screen,c.backgr,\
+                        plug_rcdic,BASEDIR,MODULESDATADIR,\
+                        CPGoodies))# call game constructor
             
             Misc.helptitle = str(game)# we need the org name for the score sheet
                                     
@@ -1001,7 +994,11 @@ def main():
                         screendim.undim()
                         
                     elif stop == 2 or stop == 1:
-                        del game
+                        try:
+                            game.__del__()
+                        except:
+                            pass
+                        del(game)
                         # reset counters for placing tux
                         c.tuxplace = 20
                         c.tuxrects = []
@@ -1015,7 +1012,7 @@ def main():
                 
                 if stop == 2 or stop == 1:
                     break
-        except MyError,info:
+        except (MyError,Exception),info:
             trace_error()
             print >> sys.stderr,'********************** ERROR *********************\n',\
                     ' A error occured in module',MyError.name,' LineNo:',MyError.line,'\n',\
@@ -1023,12 +1020,16 @@ def main():
                     ' The original error message is:\n',info,\
                     '\n**************************************************'
             stop = 2
-        
+        try:
+            game.__del__()
+        except:
+            pass
         if stop != 2:
             if c.score:
                 c.check_high_score(Misc.helptitle,c.score)
                 c.score = 0
             c.game_over()
+        
         c.screen.set_clip()
         c.backgr.set_clip()
         c.screen.blit(screendim.buffer,(0,0))
