@@ -1,28 +1,27 @@
 # -*- coding: utf-8 -*-
-"""
-     Copyright (C) 2002-2004 Stas Z <stas.zytkiewicz@gmail.com>
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
- any later version.
+# Copyright (c) 2006 Stas Zykiewicz <stas.zytkiewicz@gmail.com>
+#
+#           utils.py
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of version 2 of the GNU General Public License
+# as published by the Free Software Foundation.  A copy of this license should
+# be included in the file GPL-2.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Library General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program. If not, write to the Free Software Foundation,
- 675 Mass Ave, Cambridge, MA 02139, USA.
-
- This module provides some functions and classes for childsplay
- See the childsplay reference for more information
-"""
 import pygame,os,sys,fnmatch,traceback,operator,imp,glob,locale,\
         gettext,__builtin__,shutil,types,string
 from pygame.constants import *
 from CPConstants import *
+import BASEPATH
 
 UT_DEBUG = 0
 
@@ -32,6 +31,7 @@ class MyError(Exception):
     extra = None
 
 def set_locale(lang=None):
+    # pyfribidi comes from CPConstants
     global LOCALE_RTL,pyfribidi
     txt = ""
     try:
@@ -179,6 +179,8 @@ def replace_rcfile():
     src = os.path.join(RCDIR,CHILDSPLAYRC)
     dst = os.path.join(HOMEDIR,'ConfigData',CHILDSPLAYRC) 
     if os.path.exists(src) and os.path.exists(dst):
+        shutil.move(dst,dst+'.old')
+        print "Backup made from your old config file called %s." % dst+'.old'
         print "Replace childsplayrc file\n",src,"->\n",dst
         shutil.copyfile(src,dst)
 
@@ -205,6 +207,8 @@ class MusicObject:
         def __init__(self,filename):
             self.s = filename
         def play(self,loop=0):
+            """loop defaults to 0. values > 0 to loop a number of times.
+            -1 means loop forever."""
             pygame.mixer.music.load(self.s)
             pygame.mixer.music.play(loop)
         def stop(self):
@@ -247,8 +251,7 @@ def load_music(file):
         playmusic = NoneSound()
     else:
         playmusic = MusicObject(file)
-    
-        
+
     return playmusic
 
 def load_image(file, transparent=0, alpha=0):
@@ -272,7 +275,8 @@ def load_image(file, transparent=0, alpha=0):
     return surface.convert()
 
 def txt2surf(seq,x,y,fsize=18,title=None,box=None,fcol=(0,0,0),ttf=None):
-    """Render a list of strings in a surface with the screen backgr -> pygame surface"""
+    """Render a list of strings in a surface with the screen backgr -> pygame surface
+    x,y is the size of the surf to blit the text on."""
     space = 16 #space at the left for the text
     offset = 8 # and top
     
@@ -325,6 +329,7 @@ def char2surf(char,size,fcol=None,ttf=None):
         s = font.render(char, 1, fcol)
     except Exception,info:
         print >> sys.stderr, "ERROR in font rendering\n",info
+        return
     return s
 
 def font2surf(word,size,fcol=None,ttf=None,sizel=None):
@@ -903,8 +908,21 @@ class ChildsplayGoodies:
     """Class to provide references to a number of objects, methods, functions etc.
     These references are put in here at runtime by the childsplay main module (childsplay.py)
     and can be used by the game modules to maniputlate some aspects of childsplay.
-    The best way to query this object is to look at it from a game module."""
-    global pyfribidi
-    language = "en"
-    locale_rtl=False
-    py_fribidi = pyfribidi
+    The best way to query this object is to look at it from a game module.
+    (set DEBUG to 1 inside letters.py)"""
+    def __init__(self):
+        self.language = "en"
+        self.locale_rtl=False
+        self.pyfribidi = pyfribidi
+        self.childsplay_data_path = BASEPATH.SHAREDATADIR
+    
+    def make_vkb(self):
+        """Creates a virt_keyboard.VirtualKeyboard object.
+        Game modules must use this to get a vkb.
+        childsplay takes care of destroying it when the game ends."""
+        pass
+    def _dest_vkb(self):
+        """internally used by childsplay"""
+        pass
+        
+        
